==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/plstream_8h.js <==
var plstream_8h =
[
    [ "PLS", "classPLS.html", "classPLS" ],
    [ "Contourable_Data", "classContourable__Data.html", "classContourable__Data" ],
    [ "Coord_Xformer", "classCoord__Xformer.html", "classCoord__Xformer" ],
    [ "Coord_2d", "classCoord__2d.html", "classCoord__2d" ],
    [ "cxx_pltr2", "classcxx__pltr2.html", "classcxx__pltr2" ],
    [ "plstream", "classplstream.html", "classplstream" ],
    [ "PLcolor", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38b", [
      [ "Black", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bac1e9bce8242f443c54c7405223d616cd", null ],
      [ "Red", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bad3163c1fcda01965b692ec2c3122b743", null ],
      [ "Yellow", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38babf28513245738599d13e3ce36bd16c82", null ],
      [ "Green", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bad0784a3f969fe736e8b271a5a161d106", null ],
      [ "Cyan", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab0d4738f9c7f12049e52aa4e868bdc8b", null ],
      [ "Pink", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba500fa51afdd48f15c4176c234835c182", null ],
      [ "Tan", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab492a96cd2b9bb37c81b8451a42889d9", null ],
      [ "Grey", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba068417ac670c285e34e6e63a898e129b", null ],
      [ "DarkRed", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba556650aa9f007ea0239e66d3ddf26759", null ],
      [ "DeepBlue", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba059f250df53b7e6ea4b8b11dd9543e61", null ],
      [ "Purple", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba0102772e56e7f068bdb57bf2905f7c09", null ],
      [ "LightCyan", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba60295ab538eb50ae469a14539c220ab6", null ],
      [ "LightBlue", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba1a4360030daf53036ce1cd1668dc6243", null ],
      [ "Orchid", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba2a4b392d52ff5f8074a7ddded3984e75", null ],
      [ "Mauve", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba34037f276c915dd27b66a874ebdccfa7", null ],
      [ "White", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab548046646b36c12aa6ba841de500094", null ]
    ] ],
    [ "Contourable_Data_evaluator", "plstream_8h.html#aea4325c629efa6ce4a3ac25d113cb787", null ],
    [ "Coord_Xform_evaluator", "plstream_8h.html#a9fb0ec4fa238dfadbaa080844be6bef1", null ]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/plstream_8h.js <==
var plstream_8h =
[
    [ "PLS", "classPLS.html", "classPLS" ],
    [ "Contourable_Data", "classContourable__Data.html", "classContourable__Data" ],
    [ "Coord_Xformer", "classCoord__Xformer.html", "classCoord__Xformer" ],
    [ "Coord_2d", "classCoord__2d.html", "classCoord__2d" ],
    [ "cxx_pltr2", "classcxx__pltr2.html", "classcxx__pltr2" ],
    [ "plstream", "classplstream.html", "classplstream" ],
    [ "PLcolor", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38b", [
      [ "Black", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bac1e9bce8242f443c54c7405223d616cd", null ],
      [ "Red", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bad3163c1fcda01965b692ec2c3122b743", null ],
      [ "Yellow", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38babf28513245738599d13e3ce36bd16c82", null ],
      [ "Green", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bad0784a3f969fe736e8b271a5a161d106", null ],
      [ "Cyan", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab0d4738f9c7f12049e52aa4e868bdc8b", null ],
      [ "Pink", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba500fa51afdd48f15c4176c234835c182", null ],
      [ "Tan", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab492a96cd2b9bb37c81b8451a42889d9", null ],
      [ "Grey", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba068417ac670c285e34e6e63a898e129b", null ],
      [ "DarkRed", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba556650aa9f007ea0239e66d3ddf26759", null ],
      [ "DeepBlue", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba059f250df53b7e6ea4b8b11dd9543e61", null ],
      [ "Purple", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba0102772e56e7f068bdb57bf2905f7c09", null ],
      [ "LightCyan", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba60295ab538eb50ae469a14539c220ab6", null ],
      [ "LightBlue", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba1a4360030daf53036ce1cd1668dc6243", null ],
      [ "Orchid", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba2a4b392d52ff5f8074a7ddded3984e75", null ],
      [ "Mauve", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba34037f276c915dd27b66a874ebdccfa7", null ],
      [ "White", "plstream_8h.html#af38a775b953a654b78d0f13cf899f38bab548046646b36c12aa6ba841de500094", null ]
    ] ],
    [ "Contourable_Data_evaluator", "plstream_8h.html#aea4325c629efa6ce4a3ac25d113cb787", null ],
    [ "Coord_Xform_evaluator", "plstream_8h.html#a9fb0ec4fa238dfadbaa080844be6bef1", null ],
    [ "fill", "plstream_8h.html#af16402f2d5ccc564fc1df9cf9a336e16", null ],
    [ "tr0", "plstream_8h.html#af87ccd94cac71f8d0469e972bcde8896", null ],
    [ "tr1", "plstream_8h.html#af9d7f8e297b27d5843202e24ebbbdc94", null ],
    [ "tr2", "plstream_8h.html#aa4de81208b179d28f8876327b7dd6c7e", null ],
    [ "tr2p", "plstream_8h.html#abeb5e0d0fab7ce020df8eadfa672199f", null ]
];
